# ἐντελέχεια 【en.te.lé.kʰeː.a】

[![pypi-image]][pypi-url]
[![home-img]][home-url]
[![stai-img]][stai-url]
[![halla-img]][halla-url]
[![course-img]][course-url]
[![lecture-img]][lecture-url]
[![playground-img]][playground-url]

<!-- [![stateful-img]][stateful-url]
[![stateful_dnd-img]][stateful-url] -->

[pypi-image]: https://img.shields.io/pypi/v/entelecheia
[pypi-url]: https://pypi.org/project/entelecheia
[stai-img]: https://img.shields.io/badge/STAI-jeju.ai-blue
[stai-url]: https://stai.jeju.ai
[playground-img]: https://img.shields.io/badge/playground-app_launcher-blue
[playground-url]: https://entelecheia.cloudflareaccess.com
[halla-img]: https://img.shields.io/badge/CHU-halla.ai-blue
[halla-url]: https://halla.ai
[home-img]: https://img.shields.io/badge/youngjoon-lee-blue
[home-url]: https://youngjoon-lee.com
[home-repo-url]: https://youngjoon-lee.com/repositories
[course-img]: https://img.shields.io/badge/course-jeju.ai-blue
[course-url]: https://course.jeju.ai
[lecture-img]: https://img.shields.io/badge/lecture-jeju.ai-blue
[lecture-url]: https://lecture.jeju.ai
[research-img]: https://img.shields.io/badge/research-jeju.ai-blue
[research-url]: https://research.jeju.ai
[linkedin-img]: https://img.shields.io/badge/LinkedIn-blue?logo=linkedin
[linkedin-url]: https://www.linkedin.com/in/entelecheia/
[stateful-img]: https://badge.stateful.com/entelecheia/status.svg
[stateful-url]: https://app.stateful.com/status/entelecheia
[stateful_dnd-img]: https://badge.stateful.com/entelecheia/dnd.svg

Coined by Aristotle from ἐντελής (entelḗs, “complete, full, accomplished”) + ἔχειν (ékhein, “have, hold”).

[![entelecheia](https://github.com/entelecheia/entelecheia/assets/1177283/0a67c698-8c9e-4006-b131-d0593cd7c256)][home-url]

### Hi there, I'm Young Joon Lee 👋

🏫 I am an Assistant Professor of Artificial Intelligence Engineering and Chief Innovation Officer at Cheju Halla University in Jeju, Korea. My work spans diverse fields, integrating Artificial Intelligence, Machine Learning, and Natural Language Processing to drive innovation across multiple sectors.

🔍 My research focuses on developing cutting-edge AI solutions for real-world challenges. Recent projects include:

- Creating an AI-powered virtual physician to enhance healthcare delivery
- Pioneering AI technologies for robotic portrait drawing and visual media arts
- Developing sophisticated NLP models for various industry applications
- Exploring AI's potential in sustainable practices and ESG analysis

🌱 I'm passionate about nurturing the next generation of AI professionals. I teach a comprehensive range of AI engineering courses, from NLP and MLOps to Robotics and Operating Systems, while mentoring students in innovative research projects.

🤝 Also, I'm working to integrate AI into various aspects of Jeju's cultural and economic landscape. I'm always eager to collaborate on projects that push the boundaries of AI applications.

💬 Feel free to connect with me to explore how we can leverage AI to create impactful solutions across different fields and industries.

#### 📈 GitHub Statistics

<details>
  <summary>📊 GitHub Stats</summary>

  <a href="https://youngjoon-lee.com/repositories/">
    <img width=49% align="center" src="http://github-readme-streak-stats.entelecheia.me/?user=entelecheia&theme=transparent&hide_border=true" />
    <img width=49% align="center" src="http://github-readme-stats.entelecheia.me/api?username=entelecheia&theme=transparent&show_icons=true&hide_border=true&hide_title=true" />
  </a>
  
  [![trophy](https://github-profile-trophy.entelecheia.me/?username=entelecheia&theme=darkhub&rank=-C,-B&column=-1&no-bg=true&no-frame=true)][home-repo-url]

</details>
  
<details>
  <summary>🔥 Recent Contributions</summary>
  
  [![entelecheia's github activity graph](https://github-readme-activity-graph.entelecheia.me/graph?username=entelecheia&theme=react-dark&area=true&hide_border=true)][home-repo-url]

  [![3d contributions](https://raw.githubusercontent.com/entelecheia/metrics/main/profile-3d-contrib/profile-entelecheia.svg)][home-repo-url]

</details>
  
<details>
  <summary>🌐 Language and Topics Trajectory</summary>
  
  <a href="https://www.quine.sh/user/entelecheia">
    <img width=49% align="center" src="https://stats.quine.sh/entelecheia/topics-over-time?theme=dark" />
  </a>
  <a href="https://www.quine.sh/user/entelecheia">
    <img width=49% align="center" src="https://stats.quine.sh/entelecheia/languages-over-time?theme=dark" />
  </a>
</details>

### 🔗 Link with me on [![linkedin-img]][linkedin-url]

[![1648330290418](https://assets.entelecheia.ai/img/github-bg.jpeg)][linkedin-url]
![](https://hit.yhype.me/github/profile?user_id=1177283)
